 .. _Analysis-tools:

Analysis tools
==============

Here we provide a description of the analysis tools currently available in **lipyphilic**,
along with examples of how to perform each analysis.

.. toctree::
   :maxdepth: 1

   lib/leaflets
   lib/flip_flop
   lib/areas
   lib/neighbours
   lib/registration
